@@ -21,8 +21,9 @@ import dbus
 class PlayerBase(object):
 	"""A base for player objects"""
 	
-	def __init__(self, name, dbus_name):
+	def __init__(self, name, version, dbus_name):
 		self.name = name
+		self.version = version
 		self.dbus_name = dbus_name
 		
 		self.bus = dbus.SessionBus()
@@ -59,3 +60,17 @@ class PlayerBase(object):
 	
 	def set_volume(self, value):
 		pass
+	
+	def get_unique_id(self):
+		return "%s-%s" %(self.name, unicode(self.version))
+		
+	def get_snapshot(self):
+		"""Returns a snapshots of all the values of this player."""
+		
+		return {"volume": self.get_volume(),
+				"track": self.get_track(),
+				"name": self.name,
+				"version": self.version,
+				"is_playing": self.is_playing(),
+				"unique_id": self.get_unique_id(),
+				}
